// ===========================================================================
// CONTENT  : ABSTRACT CLASS AActionPlugin
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 08/03/2006
// HISTORY  :
//  08/03/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.cda.ui.plugin.export.spi;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.awt.Frame;

import org.pfsw.tools.cda.plugin.export.spi.AModelExporter;
import org.pfsw.tools.cda.ui.xpi.AActionPlugin;
import org.pfsw.tools.cda.xpi.PluginConfiguration;

/**
 * The purpose of this abstract exporter plugin is to provide default
 * implementations of methods that may be overridden by subclasses.
 * This is more stable in comparison to an interface, since adding new
 * methods won't break already existing subclasses.
 * <p>
 * The purpose of subclasses is to create special exporter instances (which
 * must be subclasses of AModelExporter) and to provide some meta data and
 * GUI elements for integration into CDA application.
 * <p>
 * There are only two abstract methods that definitely must be implemented by 
 * each subclass.
 * <ul>
 *   <li>getId()</li>
 *   <li>createExporter()</li>
 * </ul>
 * All subclasses must implement a public non-argument constructor!
 *
 * @author M.Duchrow
 * @version 1.0
 */
public abstract class AModelExporterUIPlugin extends AActionPlugin
{
  // =========================================================================
  // ABSTRACT PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns a new instance of an exporter.
   * <p>
   * If creation fails this method can just return null.
   * 
   * @param config The configuration for the new exporter
   */
  public abstract AModelExporter createExporter(PluginConfiguration config);

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns the configuration data that might be necessary to execute
   * the plugin's functionality
   * 
   * @param parent The parent frame from which the plugin is used
   */
  @Override
  public PluginConfiguration getConfiguration(Frame parent)
  {
    return new PluginConfiguration();
  }
}
