// ===========================================================================
// CONTENT  : INTERFACE IPluginInfo
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 10/03/2006
// HISTORY  :
//  10/03/2006  mdu  CREATED
//
// Copyright (c) 2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.cda.ui.xpi ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.awt.Frame;
import java.util.Locale;

import org.pfsw.odem.IExplorationModelObject;
import org.pfsw.tools.cda.xpi.IPluginInfo;
import org.pfsw.tools.cda.xpi.PluginConfiguration;

/**
 * Defines the methods that provide meta data about a plug-in action. 
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface IPluginActionInfo extends IPluginInfo
{ 
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	public static final IPluginActionInfo[] EMPTY_ARRAY = new IPluginActionInfo[0];
	
  // =========================================================================
  // METHODS
  // =========================================================================
	/**
   * This method must return the text to display in UI elements
   * (e.g menu item, button) on the
   * given object. If it returns null, no action widget will be added
   * to the UI. So this can also be used to control for what kind
   * of objects the plugin is available.
	 * 
	 * @param locale Defines the language the text is required for
	 * @param object An object this plug-in acts on (may be null)
   * @return The action's text or null if the given object is not supported
	 */
	public String getActionText( Locale locale, IExplorationModelObject object ) ;
	
	// -------------------------------------------------------------------------
	
	/**
	 * Returns the text that should be shown as tooltip for this action.
	 * 
	 * @param locale Represents the language the text is required for
	 * @param object An object this plug-in acts on (may be null)
	 * @return A text or null to indicate that there is no tooltip text
	 */
	public String getToolTipText( Locale locale, IExplorationModelObject object ) ;
	
	// -------------------------------------------------------------------------
	
	/**
	 * Returns the filename of an icon image to that should be shown if the 
	 * plug-in can be used.
	 * 
	 * @param object An object this plug-in acts on (may be null)
	 * @return An filename of a graphics file or null 
	 */
	public String getEnabledIconFilename( IExplorationModelObject object ) ;
	
	// -------------------------------------------------------------------------
	
	/**
	 * Returns the name of an icon file that should be shown in the UI when the 
	 * plug-in cannot be used.
	 * 
	 * @param object An object this plug-in acts on (may be null)
	 * @return An filename of a graphics file or null 
	 */
	public String getDisabledIconFilename( IExplorationModelObject object ) ; 

	// -------------------------------------------------------------------------
  
	/**
	 * The method gets called to allow the plug-in collecting configuration
	 * parameters if necessary for execution.
	 * Returning null means, execution of the plug-in has been cancelled.
	 * If a configuration object is returned execution can be started.
	 * 
	 * @param parentFrame The frame from which this method gets called.
	 * @return A configuration or null
	 */
	public PluginConfiguration getConfiguration( Frame parentFrame ) ;
	
	// -------------------------------------------------------------------------
	
} // interface IPluginActionInfo 
